@@ -26,28 +26,16 @@
 #define EEL_H
 
 #include <eel/eel-art-extensions.h>
-#include <eel/eel-art-gtk-extensions.h>
-#include <eel/eel-background.h>
-#include <eel/eel-enumeration.h>
-#include <eel/eel-gconf-extensions.h>
 #include <eel/eel-gdk-extensions.h>
 #include <eel/eel-gdk-pixbuf-extensions.h>
 #include <eel/eel-glib-extensions.h>
 #include <eel/eel-gnome-extensions.h>
 #include <eel/eel-graphic-effects.h>
-#include <eel/eel-gtk-container.h>
 #include <eel/eel-gtk-extensions.h>
 #include <eel/eel-gtk-macros.h>
-#include <eel/eel-image-table.h>
-#include <eel/eel-labeled-image.h>
-#include <eel/eel-pango-extensions.h>
-#include <eel/eel-preferences.h>
 #include <eel/eel-self-checks.h>
 #include <eel/eel-stock-dialogs.h>
 #include <eel/eel-string.h>
-#include <eel/eel-types.h>
 #include <eel/eel-vfs-extensions.h>
-#include <eel/eel-wrap-table.h>
-#include <eel/eel-xml-extensions.h>
 
 #endif /* EEL_H */
