@@ -29,7 +29,6 @@
 #include "nautilus-directory-notify.h"
 #include "nautilus-directory-private.h"
 #include "nautilus-file-private.h"
-#include "nautilus-autorun.h"
 #include <eel/eel-gtk-macros.h>
 #include <glib/gi18n.h>
 
@@ -48,7 +47,7 @@ vfs_file_monitor_add (NautilusFile *file,
 {
 	nautilus_directory_monitor_add_internal
 		(file->details->directory, file,
-		 client, TRUE, TRUE, attributes, NULL, NULL);
+		 client, TRUE, attributes, NULL, NULL);
 }   
 			   
 static void
