@@ -28,7 +28,6 @@
 #include <glib-object.h>
 #include <libnautilus-private/nautilus-view.h>
 #include <gtk/gtk.h>
-#include "../src/nautilus-bookmark-list.h"
 
 G_BEGIN_DECLS
 
@@ -83,6 +82,10 @@ typedef NautilusWindow                  NautilusWindowInfo;
 
 typedef struct _NautilusWindowInfoIface NautilusWindowInfoIface;
 
+typedef void (* NautilusWindowGoToCallback) (NautilusWindow *window,
+                                             GError *error,
+                                             gpointer user_data);
+
 struct _NautilusWindowInfoIface 
 {
 	GTypeInterface g_iface;
@@ -127,8 +130,6 @@ struct _NautilusWindowInfoIface
 					  const char *status);
 	char * (* get_title)             (NautilusWindowInfo *window);
 	GList *(* get_history)           (NautilusWindowInfo *window);
-	NautilusBookmarkList *  
-	       (* get_bookmark_list)     (NautilusWindowInfo *window);
 	NautilusWindowType
 	       (* get_window_type)       (NautilusWindowInfo *window);
 	NautilusWindowShowHiddenFilesMode
@@ -139,6 +140,10 @@ struct _NautilusWindowInfoIface
 	NautilusWindowSlotInfo * (* get_active_slot) (NautilusWindowInfo *window);
 	NautilusWindowSlotInfo * (* get_extra_slot)  (NautilusWindowInfo *window);
 
+	gboolean (* get_initiated_unmount) (NautilusWindowInfo *window);
+	void   (* set_initiated_unmount) (NautilusWindowInfo *window,
+					  gboolean initiated_unmount);
+
 	void   (* view_visible)        (NautilusWindowInfo *window,
 					NautilusView *view);
 	void   (* close_window)       (NautilusWindowInfo *window);
@@ -163,13 +168,15 @@ void                              nautilus_window_info_push_status
 NautilusWindowType                nautilus_window_info_get_window_type          (NautilusWindowInfo                *window);
 char *                            nautilus_window_info_get_title                (NautilusWindowInfo                *window);
 GList *                           nautilus_window_info_get_history              (NautilusWindowInfo                *window);
-NautilusBookmarkList *		  nautilus_window_info_get_bookmark_list        (NautilusWindowInfo                *window);
 char *                            nautilus_window_info_get_current_location     (NautilusWindowInfo                *window);
 int                               nautilus_window_info_get_selection_count      (NautilusWindowInfo                *window);
 GList *                           nautilus_window_info_get_selection            (NautilusWindowInfo                *window);
 NautilusWindowShowHiddenFilesMode nautilus_window_info_get_hidden_files_mode    (NautilusWindowInfo                *window);
 void                              nautilus_window_info_set_hidden_files_mode    (NautilusWindowInfo                *window,
 										 NautilusWindowShowHiddenFilesMode  mode);
+gboolean                          nautilus_window_info_get_initiated_unmount    (NautilusWindowInfo                *window);
+void                              nautilus_window_info_set_initiated_unmount    (NautilusWindowInfo                *window,
+										 gboolean initiated_unmount);
 GtkUIManager *                    nautilus_window_info_get_ui_manager           (NautilusWindowInfo                *window);
 
 G_END_DECLS
