@@ -53,14 +53,11 @@ EEL_IMPLEMENT_MUST_OVERRIDE_SIGNAL (nautilus_navigation_bar, set_location)
 static void
 nautilus_navigation_bar_class_init (NautilusNavigationBarClass *klass)
 {
-	GtkObjectClass *object_class;
 	GtkBindingSet *binding_set;
 
-	object_class = GTK_OBJECT_CLASS (klass);
-	
 	signals[ACTIVATE] = g_signal_new
 		("activate",
-		 G_TYPE_FROM_CLASS (object_class),
+		 G_TYPE_FROM_CLASS (klass),
 		 G_SIGNAL_RUN_LAST,
 		 G_STRUCT_OFFSET (NautilusNavigationBarClass,
 				    activate),
@@ -70,7 +67,7 @@ nautilus_navigation_bar_class_init (NautilusNavigationBarClass *klass)
 
 	signals[CANCEL] = g_signal_new
 		("cancel",
-		 G_TYPE_FROM_CLASS (object_class),
+		 G_TYPE_FROM_CLASS (klass),
 		 G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION,
 		 G_STRUCT_OFFSET (NautilusNavigationBarClass,
 				    cancel),
@@ -80,7 +77,7 @@ nautilus_navigation_bar_class_init (NautilusNavigationBarClass *klass)
 
 	signals[LOCATION_CHANGED] = g_signal_new
 		("location_changed",
-		 G_TYPE_FROM_CLASS (object_class),
+		 G_TYPE_FROM_CLASS (klass),
 		 G_SIGNAL_RUN_LAST,
 		 G_STRUCT_OFFSET (NautilusNavigationBarClass,
 				    location_changed),
@@ -92,7 +89,7 @@ nautilus_navigation_bar_class_init (NautilusNavigationBarClass *klass)
 	klass->cancel = NULL;
 
 	binding_set = gtk_binding_set_by_class (klass);
-	gtk_binding_entry_add_signal (binding_set, GDK_Escape, 0, "cancel", 0);
+	gtk_binding_entry_add_signal (binding_set, GDK_KEY_Escape, 0, "cancel", 0);
 
 	EEL_ASSIGN_MUST_OVERRIDE_SIGNAL (klass, nautilus_navigation_bar, get_location);
 	EEL_ASSIGN_MUST_OVERRIDE_SIGNAL (klass, nautilus_navigation_bar, set_location);
