@@ -230,29 +230,6 @@ button_press_cb (NautilusNotebook *notebook,
 static void
 nautilus_notebook_init (NautilusNotebook *notebook)
 {
-	static const gchar css_custom[] =
-	  "#nautilus-tab-close-button {"
-	  "  -GtkWidget-focus-padding : 0;"
-	  "  -GtkWidget-focus-line-width: 0;"
-	  "  xthickness: 0;"
-	  "  ythickness: 0;"
-	  "}";
-
-	GError *error = NULL;
-	GtkCssProvider *provider = gtk_css_provider_new ();
-	gtk_css_provider_load_from_data (provider, css_custom, -1, &error);
-
-	if (error != NULL) {
-		g_warning ("Can't parse NautilusNotebook's CSS custom description: %s\n", error->message);
-		g_error_free (error);
-	} else {
-		gtk_style_context_add_provider (gtk_widget_get_style_context (GTK_WIDGET (notebook)),
-						GTK_STYLE_PROVIDER (provider),
-						GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
-	}
-
-	g_object_unref (provider);
-
 	gtk_notebook_set_scrollable (GTK_NOTEBOOK (notebook), TRUE);
 	gtk_notebook_set_show_border (GTK_NOTEBOOK (notebook), FALSE);
 	gtk_notebook_set_show_tabs (GTK_NOTEBOOK (notebook), FALSE);
