@@ -308,9 +308,7 @@ nautilus_window_slot_set_title (NautilusWindowSlot *slot,
 		slot->title = g_strdup (title);
 	}
 
-	if (eel_strlen (slot->title) > 0 && slot->current_location_bookmark &&
-	    nautilus_bookmark_set_name (slot->current_location_bookmark,
-					slot->title)) {
+	if (eel_strlen (slot->title) > 0 && slot->current_location_bookmark) {
 		changed = TRUE;
 
 		/* Name of item in history list changed, tell listeners. */
